# Sphinx autoindex extension
This Sphinx extension has for purpose to provide auto indexer extension who works like autoapi before generation the source just before to build but use autodoc to document your code and is compatible with pydantic extension, attrs and other extension that depend from autodoc usage.

[!WARNING]
This package is not ready for production environment. If you see bugs or have idea to improve it let an issue Thanks

## Documentation
You can see how to use this extension here
[Documentation](https://mickaeldescamps.github.io/sphinx-autoindex/api/extension.html)

## Report a Bug, have an Idea ? 
Do not hesitate to report bug or publish your idea to improve this extension with an issue.